@@ -23,7 +23,7 @@
 #include <QString>
 #include <QUrl>
 
-#include <quazip5/quazip.h>
+#include <quazip.h>
 #include "writer/structure/contentxml.h"
 #include "calcwriterinterface.h"
 #include "writer/structure/settingsxml.h"
